CHANGELOG
=========

0.1.1
----------

- enabled pushing to pypi via tags in travis.

0.1.0
----------

- enabled disabled tests for cloudformation, iam and sns because of new version of moto library (0.4.10).

0.0.1
----------

- support of most of server modes provided by moto.
- full testing of all available fixures.
